package internal

import "go.opentelemetry.io/otel/exporters/otlp/otlptrace/otlptracegrpc/internal"

Package internal provides internal functionally for the otlptracegrpc package.

Index

Functions

func MetricPartialSuccessError

func MetricPartialSuccessError(itemsRejected int64, errorMessage string) error

MetricPartialSuccessError returns an error describing a partial success response for the metric signal.

func TracePartialSuccessError

func TracePartialSuccessError(itemsRejected int64, errorMessage string) error

TracePartialSuccessError returns an error describing a partial success response for the trace signal.

Types

type PartialSuccess

type PartialSuccess struct {
	ErrorMessage  string
	RejectedItems int64
	RejectedKind  string
}

PartialSuccess represents the underlying error for all handling OTLP partial success messages. Use `errors.Is(err, PartialSuccess{})` to test whether an error passed to the OTel error handler belongs to this category.

func (PartialSuccess) Error

func (ps PartialSuccess) Error() string

Error implements the error interface.

func (PartialSuccess) Is

func (ps PartialSuccess) Is(err error) bool

Is supports the errors.Is() interface.

Source Files

gen.go partialsuccess.go

Directories

PathSynopsis
internal/envconfigPackage envconfig provides functionality to parse configuration from environment variables.
internal/otlpconfigPackage otlpconfig provides configuration for the otlptrace exporters.
internal/otlptracetestPackage otlptracetest provides testing utilities and framework for the otlptrace exporters.
internal/retryPackage retry provides request retry functionality that can perform configurable exponential backoff for transient errors and honor any explicit throttle responses received.
Version
v1.37.0 (latest)
Published
Jun 25, 2025
Platform
linux/amd64
Imports
1 packages
Last checked
10 months ago

Tools for package owners.